@@ -2,7 +2,7 @@
 Cucumber result to Jira Xray Test repository
 
 """
-__version__ = "0.4.4"
+__version__ = "0.4.5"
 
 
 import datetime
@@ -41,7 +41,10 @@ class CuJiraX:
         self.result_info.finishDate = date
 
     def set_testexecution(self, jira_key: str):
-        self.testexecution = Jirakey(jira_key)
+        try:
+            self.testexecution = Jirakey(jira_key)
+        except TypeError:
+            self.testexecution = None
 
     def set_test_environments(self, environments: list):
         self.result_info.testEnvironments = environments
